@@ -1,15 +1,16 @@
-# Copyright (c) 2000-2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 package Net::LDAP::Extra;
 
 use strict;
+use vars qw($VERSION);
 
 require Net::LDAP;
 require Carp;
 
-our $VERSION = "0.02";
+$VERSION = "0.01";
 
 sub import {
   shift;
@@ -51,15 +52,11 @@ sub-classes just so they can get all the features.
 C<Net::LDAP::Extra> allows methods to be added directly to
 all Net::LDAP objects. This can be done by creating a class
 C<Net::LDAP::Extra::name> which exports functions. A
-C<use Net::LDAP::Extra qw(name)> will then make these functions available
+C<use Net::LDAP::Extra qw(name)> will then make these functions avaliable
 as a methods on all C<Net::LDAP> objects.
 
 Care should be taken when choosing names for the functions to export
 to ensure that they do not clash with others.
 
-=head1 SEE ALSO
-
-L<Net::LDAP::Extra::AD>,
-
 =cut
 
